package com.factory.web.service.pm;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.factory.base.entity.aggregates.PageBean;
import com.factory.base.entity.aggregates.ResponseBean;
import com.factory.base.entity.po.benteler.BentelerPlan;
import com.factory.web.entity.pm.OnsiteItem;
import com.factory.web.entity.pm.OnsiteWorkshop;
import com.factory.web.entity.pm.req.AddPmPlanReq;
import com.factory.web.entity.pm.req.EditPmPlanReq;
import com.factory.web.entity.pm.req.PmPlanPauseFlagReq;
import com.factory.web.entity.pm.req.SearchPmItemResultListReq;
import com.factory.web.entity.pm.req.SearchPmPlanListForPadReq;
import com.factory.web.entity.pm.req.SearchPmPlanListReq;
import com.factory.web.entity.pm.req.SearchPmPlanReq;
import com.factory.web.entity.pm.req.SearchWorkshopReq;
import com.factory.web.entity.pm.res.PmItemResultListRes;
import com.factory.web.entity.pm.res.PmPlanListForPadRes;
import com.factory.web.entity.pm.res.PmPlanListRes;
import com.factory.web.entity.pm.res.PmPlanRes;

/**
 * 防错计划
 *
 * @author wzy
 * @date 2021-07-09 12:00:00
 */
public interface PreventMistakeService extends IService<BentelerPlan> {
	
	/**
     * 新建防错计划
     * @param req
     * @return 
     */
	public ResponseBean addPmPlan(AddPmPlanReq req);

	/**
     * 校验计划名是否存在
     * @param name
     * @return true存在，false不存在
     */
    public boolean checkPlanNameExist(String name);
    
    /**
     * 校验工作站名是否存在
     * @param wsName
     * @return true存在，false不存在
     */
    public boolean checkWsNameExist(String wsName);

    /**
     * 取得防错计划列表
     * @param req
     * @return 防错计划列表
     */
    public ResponseBean<PageBean<PmPlanListRes>> getPmPlanList(SearchPmPlanListReq req);
    
    /**
     * 取得防错计划信息
     * @param req
     * @return 防错计划信息
     */
    public ResponseBean<PmPlanRes> getPmPlan(SearchPmPlanReq req);
    
    /**
     * 禁用解禁防错计划
     * @param req
     * @return 
     */
    public ResponseBean disablePmPlan(PmPlanPauseFlagReq req);
    
    /**
     * 取得工作站信息
     * @param req
     * @return 工作站信息
     */
    public ResponseBean<OnsiteWorkshop> getWorkshop(SearchWorkshopReq req);
    
    /**
     * 修改防错计划
     * @param req
     * @return 
     */
	public ResponseBean editPmPlan(EditPmPlanReq req);

    /**
     * 取得检查记录列表
     * @param req
     * @return 检查记录列表
     */
    public ResponseBean<List<PmItemResultListRes>> getPmItemResultList(SearchPmItemResultListReq req);
    
    /**
     * 取得Pad端防错计划列表
     * @param req
     * @return Pad端防错计划列表
     */
    public ResponseBean<List<PmPlanListForPadRes>> getPmPlanListForPad(SearchPmPlanListForPadReq req);
    
    /**
     * 取得工作站列表
     * @param req
     * @return 工作站列表
     */
    public ResponseBean<List<OnsiteWorkshop>> getWorkshopList(SearchPmPlanReq req);
    
    /**
     * 取得巡检项目列表
     * @param req
     * @return 巡检项目列表
     */
    public ResponseBean<List<OnsiteItem>> getItemList(SearchWorkshopReq req);

}
